@@ -74,10 +74,10 @@ using namespace scim;
 #define SCIM_CONFIG_PANEL_VKB_GTK_VKB_PARAMETERS            "/Panel/VKB/Gtk/VKBParameters"
 #define SCIM_CONFIG_PANEL_VKB_GTK_VKB_WIDTH                 "/Panel/VKB/Gtk/VKB_Width"
 #define SCIM_CONFIG_PANEL_VKB_GTK_VKB_HEIGHT                "/Panel/VKB/Gtk/VKB_Height"
-#define SCIM_DEFAULT_VKB_PROGRAM                            "matchbox-keyboard"
+#define SCIM_DEFAULT_VKB_PROGRAM                            "fvkbd-gtk"
 #define SCIM_DEFAULT_VKB_PARAMETERS                         "--xid"
 #define SCIM_DEFAULT_VKB_WINDOW_WIDTH                       800
-#define SCIM_DEFAULT_VKB_WINDOW_HEIGHT                      200
+#define SCIM_DEFAULT_VKB_WINDOW_HEIGHT                      250
 #define SCIM_DEFAULT_VKB_DOCKPANEL                          true
 #define SCIM_DEFAULT_VKB_PANEL_EXTEND                       true
 
@@ -153,7 +153,7 @@ static bool   __config_vkb_panel_extend          = bool (SCIM_DEFAULT_VKB_PANEL_
 static gint   __config_vkb_window_width          = gint (SCIM_DEFAULT_VKB_WINDOW_WIDTH);
 static gint   __config_vkb_window_height         = gint (SCIM_DEFAULT_VKB_WINDOW_HEIGHT);
 
-static String __config_font                      = _("default");
+static String __config_font                      = _("sans 16");
 static String __config_vkb_program               = String (SCIM_DEFAULT_VKB_PROGRAM);
 static String __config_vkb_parameters            = String (SCIM_DEFAULT_VKB_PARAMETERS);
 
